macro_rules! match_all_dynamic_fmts {
($self:expr_2021, $x:ident, $block:expr_2021, $err:expr_2021) => { ... };
}Expand description
Macro to match all dynamic pixel formats and execute a block of code with a typed image reference.
macro_rules! match_all_dynamic_fmts {
($self:expr_2021, $x:ident, $block:expr_2021, $err:expr_2021) => { ... };
}Macro to match all dynamic pixel formats and execute a block of code with a typed image reference.